import java.awt.*;
import java.awt.image.BufferStrategy;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageFilter;
import java.lang.reflect.InvocationTargetException;
import javax.swing.*;

public class ScreenManager {
	
	private GraphicsDevice gd;
	
	public ScreenManager(){
		GraphicsEnvironment e = GraphicsEnvironment.getLocalGraphicsEnvironment();
		gd = e.getDefaultScreenDevice();	
	}
	
	public DisplayMode[] getCompatibleDisplayModes(){
		return gd.getDisplayModes();
	}
	
	public DisplayMode findFirstCompatibleMode(DisplayMode modes[]){
		DisplayMode goodmodes[] = gd.getDisplayModes();
		for(int x = 0; x < modes.length; x++){
			for(int y = 0; y < goodmodes.length; y++){
				if(DisplayModesMatch(modes[x],goodmodes[y])){
					return modes[x];
				}
			}
		}
		return null;
	}
	public DisplayMode getDisplaymode(){
		return gd.getDisplayMode();
	}
	public boolean DisplayModesMatch(DisplayMode a, DisplayMode b){
		if(a.getWidth() != b.getWidth() || a.getHeight() != b.getHeight()){
			return false;
		}
		if(a.getBitDepth() != DisplayMode.BIT_DEPTH_MULTI && b.getBitDepth() != DisplayMode.BIT_DEPTH_MULTI && a.getBitDepth() != b.getBitDepth() ){
			return false;
		}
		if(a.getRefreshRate() != DisplayMode.REFRESH_RATE_UNKNOWN && b.getRefreshRate() != DisplayMode.REFRESH_RATE_UNKNOWN && a.getRefreshRate() != b.getRefreshRate()){
			return false;
		}
		
		return true;
	}
	public void setFull(DisplayMode dm){
		JFrame f = new JFrame();
		f.setUndecorated(true);
		f.setIgnoreRepaint(true);
		f.setResizable(true);
		gd.setFullScreenWindow(f);
		
		if(dm != null && gd.isDisplayChangeSupported()){
			try{
				gd.setDisplayMode(dm);
			}catch(Exception ex){}
			f.createBufferStrategy(2);
		}
	}
	
	public Graphics2D getGraphics(){
		Window w = gd.getFullScreenWindow();
		if(w != null){
			BufferStrategy s = w.getBufferStrategy();
			return (Graphics2D)s.getDrawGraphics();
		}else{
			return null;
		}
	}
	
	public void update(){
		Window w = gd.getFullScreenWindow();
		if(w != null){
			BufferStrategy s = w.getBufferStrategy();
			if(!s.contentsLost()){
				s.show();
			}
		}
	}
	public Window getFullScreenWindow(){
		return gd.getFullScreenWindow();
	}
	public int getWidth(){
		Window w = gd.getFullScreenWindow();
		if(w != null){
			return w.getWidth();
		}else{
			return 0;
		}
	}
	public int getHeight(){
		Window w = gd.getFullScreenWindow();
		if(w != null){
			return w.getHeight();
		}else{
			return 0;
		}
	}
	public void restoreScreen(){
		Window w = gd.getFullScreenWindow();
		if(w != null){
			w.dispose();
		}
		gd.setFullScreenWindow(null);
	}
	public BufferedImage createCompatImage(int w, int h, int t){
		Window win = gd.getFullScreenWindow();
		if(win != null){
			GraphicsConfiguration gc = win.getGraphicsConfiguration();
			return gc.createCompatibleImage(w,h,t);
		}
		return null;
	}
		
}
